@@ -5,7 +5,7 @@ void Alternatives::globHead(string const &initial, string searchCmd,
 try
 {
     for (size_t idx = 0; idx != searchCmd.length(); )
-        globPattern(initial, searchCmd, ++idx, context);
+        globPattern(initial, searchCmd, &idx, context);
 }
 catch (bool headHasSlash)
 {}
