@@ -1,6 +1,6 @@
 //                     usage.cc
 
-#include "xd.ih"
+#include "main.ih"
 
 void usage(std::string  const  &progname)
 {
